@@ -92,7 +92,7 @@ class CIGitLab(CIBase):
             current_branch = os.getenv("CI_COMMIT_BRANCH", "unknown-branch")
             # This is the unique key that git uses to refer to the blob type data object for the lockfile.
             # Reference: https://git-scm.com/book/en/v2/Git-Internals-Git-Objects
-            cmd = f"git hash-object {self.lockfile}".split()
+            cmd = ["git", "hash-object", str(self.lockfile)]
             lockfile_hash_object = subprocess.run(cmd, check=True, text=True, capture_output=True).stdout.strip()
             label = f"{self.ci_platform_name}_{current_branch}_{lockfile_hash_object[:7]}"
 
@@ -125,7 +125,7 @@ class CIGitLab(CIBase):
             default_branch = os.getenv("CI_DEFAULT_BRANCH", "HEAD")
             # This is a best effort attempt since it is finding the merge base between the current commit
             # and the default branch instead of finding the exact commit from which the branch was created.
-            cmd = f"git merge-base HEAD refs/remotes/{remote}/{default_branch}".split()
+            cmd = ["git", "merge-base", "HEAD", f"refs/remotes/{remote}/{default_branch}"]
             try:
                 common_ancestor_commit = subprocess.run(cmd, check=True, capture_output=True, text=True).stdout.strip()
             except subprocess.CalledProcessError as err:
@@ -146,8 +146,8 @@ class CIGitLab(CIBase):
         try:
             # `--exit-code` will make git exit with 1 if there were differences while 0 means no differences.
             # Any other exit code is an error and a reason to re-raise.
-            cmd = f"git diff --exit-code --quiet {diff_base_sha} -- {lockfile.resolve()}"
-            subprocess.run(cmd.split(), check=True)
+            cmd = ["git", "diff", "--exit-code", "--quiet", diff_base_sha, "--", str(lockfile.resolve())]
+            subprocess.run(cmd, check=True)
             return False
         except subprocess.CalledProcessError as err:
             if err.returncode == 1:
